# terminal-tracker

Maintaining and organizing a history of terminal commands executed for a folder/project from any terminal.

![](https://img.shields.io/github/license/MiloniAtal/terminal-tracker)
![](https://img.shields.io/github/issues/MiloniAtal/terminal-tracker)
## Overview

A tool that maintains history of all executed commands of a project or folder. It can be used to record your terminal sessions for later analysis or to share your commands with others. It also provides some extra functionality such as command search, tagging and filtering. 
